@@ -23,16 +23,18 @@ class Sample:
 
         func = partial(sample_it, n=n)
         return (
-            self._ldf.with_columns(pl.first().map(func).alias("_sample"))
+            self._ldf.with_columns(
+                pl.first().map_batches(func, return_dtype=pl.Boolean).alias("_sample")
+            )
             .filter(pl.col("_sample"))
             .drop("_sample")
         )
 
     def height(self):
-        return self._ldf.select(pl.first().count()).collect().item()
+        return self._ldf.select(pl.first().len()).collect().item()
 
     def shape(self):
-        return (self.height(), len(self._ldf.columns))
+        return (self.height(), len(self._ldf.collect_schema().names()))
 
     def item(self):
         if self.shape() == (1, 1):
